@@ -359,11 +359,16 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
   int ilambda_max=0;
   int mstart=0;
   int mend=0;
-
+  int code_extrap=1048576;
+  //int code_special=2143289343;
+  int code_special=2147483647;
+  int decode_bp = instrument->decode_bp;
+  //decode_bp = code_special;
   /* check if there are bad pixels to be interpolated, else we can integrate */
   for (islit = slit_min; islit <= slit_max; islit++) {
     idx = islit * nlambda + ilambda;
-    if ((qual[idx] & instrument->decode_bp) > 0) {
+    if (( qual[idx] & decode_bp ) > 0) {
+    //if ((qual[idx] & code_special) > 0) {
       nbad++;
     }
   }
@@ -403,7 +408,9 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
       for (islit = slit_min; islit <= slit_max; islit++) {
         mdx = islit * nlambda + ilambda + m;
         //xsh_msg("qual[%d,%d]=%d",m,islit,qual[mdx]);
-        if ((qual[mdx] & instrument->decode_bp) > 0) {
+        if (( qual[mdx] & decode_bp ) > 0) {
+
+        //if ((qual[mdx] & code_special) > 0) {
           pflag[m-mstart]=1;
           nflag++;
           break;
@@ -411,6 +418,9 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
       }
     }
 
+    //xsh_msg("m_start=%d m_end=%d",mstart,mend);
+    
+
     /* if all wavelength within the extraction mask have at least one bad pixel then throw exception */
     if (nflag == mask_size) {
       /* 2a: exception: Too few good pixels for interpolation, flag this pixel */
@@ -441,7 +451,8 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
       den_fct = 0;
       for (islit = slit_min; islit <= slit_max; islit++) {
         idx = islit * nlambda + ilambda;
-        if ((qual[idx] & instrument->decode_bp) == 0) {
+        if (( qual[idx] & decode_bp ) == 0) {
+        //if ((qual[idx] & code_special) == 0) {
           err2 = errs[idx] * errs[idx];
           inv_err2=1./ err2;
           num_fct += prof[islit] * flux[idx] * inv_err2;
@@ -454,7 +465,8 @@ cpl_error_code xsh_extract_clean_slice(const float* flux, const float* errs,
       //xsh_msg("slit_min=%d slit_max=%d",slit_min,slit_max);
       for (islit = slit_min; islit <= slit_max; islit++) {
         idx = islit * nlambda + ilambda;
-        if ((qual[idx] & instrument->decode_bp) == 0) {
+        if ((qual[idx] & decode_bp ) == 0) {
+        //if ((qual[idx] & code_special) == 0) {
           *fluxval += flux[idx];
           *errval += (errs[idx] * errs[idx]);
           *qualval |= qual[idx];
